@@ -22,16 +22,20 @@ def get_app():
     _ = install
     app.command("install", no_args_is_help=True, help="🛠️ [i] Install essential packages")(install)
     app.command("i", no_args_is_help=True, help="Install essential packages", hidden=True)(install)
-    app.add_typer(cli_repos.get_app(), name="repos")
-    app.add_typer(cli_repos.get_app(), name="r", hidden=True)
-    app.add_typer(cli_config.get_app(), name="config")
-    app.add_typer(cli_config.get_app(), name="c", hidden=True)
+    app_repos = cli_repos.get_app()
+    app.add_typer(app_repos, name="repos")
+    app.add_typer(app_repos, name="r", hidden=True)
+    app_config = cli_config.get_app()
+    app.add_typer(app_config, name="config")
+    app.add_typer(app_config, name="c", hidden=True)
     app.add_typer(cli_data.app_data, name="data")
     app.add_typer(cli_data.app_data, name="d", hidden=True)
-    app.add_typer(cli_self.get_app(), name="self")
-    app.add_typer(cli_self.get_app(), name="s", hidden=True)
-    app.add_typer(cli_network.get_app(), name="network")
-    app.add_typer(cli_network.get_app(), name="n", hidden=True)
+    app_self = cli_self.get_app()
+    app.add_typer(app_self, name="self")
+    app.add_typer(app_self, name="s", hidden=True)
+    app_nw = cli_network.get_app()
+    app.add_typer(app_nw, name="network")
+    app.add_typer(app_nw, name="n", hidden=True)
     return app
 
 def main():
