@@ -1,4 +1,3 @@
-#!/usr/bin/env -S uv run --no-dev --project /home/alex/code/machineconfig --script
 """Sx & Rx
 
 TODO: add support for cases in which source or target has non 22 default port number and is defineda as user@host:port:path which makes 2 colons in the string.
@@ -13,14 +12,14 @@ from rich.panel import Panel
 
 from machineconfig.utils.ssh import SSH
 from machineconfig.utils.path_extended import PathExtended
-from machineconfig.scripts.python.helpers.helpers2 import ES
+from machineconfig.scripts.python.cloud_helpers.helpers2 import ES
 from machineconfig.utils.accessories import pprint
 
 
 console = Console()
 
 
-def main(
+def ftpx(
     source: Annotated[str, typer.Argument(help="Source path (machine:path)")],
     target: Annotated[str, typer.Argument(help="Target path (machine:path)")],
     recursive: Annotated[bool, typer.Option("--recursive", "-r", help="Send recursively.")] = False,
@@ -106,7 +105,7 @@ def main(
     from paramiko.ssh_exception import AuthenticationException  # type: ignore
 
     try:
-        ssh = SSH(rf"{machine}")
+        ssh = SSH(host=rf"{machine}", username=None, hostname=None, ssh_key_path=None, password=None, port=22, enable_compression=True)
     except AuthenticationException:
         console.print(
             Panel(
@@ -124,7 +123,7 @@ def main(
         import getpass
 
         pwd = getpass.getpass()
-        ssh = SSH(rf"{machine}", pwd=pwd)
+        ssh = SSH(host=rf"{machine}", username=None, hostname=None, ssh_key_path=None, password=pwd, port=22, enable_compression=True)
 
     if cloud:
         console.print(
@@ -134,7 +133,7 @@ def main(
                 border_style="cyan",
             )
         )
-        ssh.run(f"cloud_copy {resolved_source} :^", desc="Uploading from remote to the cloud.").print()
+        ssh.run_shell(command=f"cloud_copy {resolved_source} :^", verbose_output=True, description="Uploading from remote to the cloud.", strict_stderr=False, strict_return_code=False)
         console.print(
             Panel.fit(
                 "⬇️  Cloud transfer mode — downloading from cloud to local...",
@@ -142,7 +141,7 @@ def main(
                 border_style="cyan",
             )
         )
-        ssh.run_locally(f"cloud_copy :^ {resolved_target}").print()
+        ssh.run_locally(command=f"cloud_copy :^ {resolved_target}")
         received_file = PathExtended(resolved_target)  # type: ignore
     else:
         if source_is_remote:
@@ -164,7 +163,7 @@ def main(
                     padding=(1, 2),
                 )
             )
-            received_file = ssh.copy_to_here(source=resolved_source, target=resolved_target, z=zipFirst, r=recursive)
+            received_file = ssh.copy_to_here(source=resolved_source, target=resolved_target, compress_with_zip=zipFirst, recursive=recursive)
         else:
             assert resolved_source is not None, """
 ❌ Path Error: Target must be a remote path (machine:path)"""
@@ -184,7 +183,7 @@ def main(
                     padding=(1, 2),
                 )
             )
-            received_file = ssh.copy_from_here(source=resolved_source, target=resolved_target, z=zipFirst, r=recursive)
+            received_file = ssh.copy_from_here(source_path=resolved_source, target_path=resolved_target, compress_with_zip=zipFirst, recursive=recursive, overwrite_existing=False)
 
     if source_is_remote and isinstance(received_file, PathExtended):
         console.print(
@@ -211,10 +210,12 @@ def main(
     )
 
 
-def main_from_parser() -> None:
+def main() -> None:
     """Entry point function that uses typer to parse arguments and call main."""
-    typer.run(main)
+    app = typer.Typer()
+    app.command(no_args_is_help=True, help="File transfer utility though SSH.")(ftpx)
+    app()
 
 
 if __name__ == "__main__":
-    main_from_parser()
+    main()
