@@ -2,7 +2,6 @@
 from pathlib import Path
 from typing import Optional, Literal
 import typer
-from machineconfig.scripts.python.sessions_multiprocess import create_from_function
 
 def balance_load(layout_path: Path = typer.Argument(..., help="Path to the layout.json file"),
            max_thresh: int = typer.Option(..., help="Maximum tabs per layout"),
@@ -26,7 +25,7 @@ def balance_load(layout_path: Path = typer.Argument(..., help="Path to the layou
 def select_layout(layouts_json_file: Path, selected_layouts_names: Optional[list[str]], select_interactively: bool) -> list["LayoutConfig"]:
     import json
     from machineconfig.utils.options import choose_from_options
-    from machineconfig.utils.schemas.layouts.layout_types import LayoutConfig, LayoutsFile
+    from machineconfig.utils.schemas.layouts.layout_types import LayoutsFile
     layout_file: LayoutsFile = json.loads(layouts_json_file.read_text(encoding="utf-8"))
     if len(layout_file["layouts"]) == 0:
         raise ValueError(f"No layouts found in {layouts_json_file}")
@@ -52,7 +51,7 @@ def select_layout(layouts_json_file: Path, selected_layouts_names: Optional[list
 
 def find_layout_file(layout_path: str, ) -> Path:
     from machineconfig.utils.path_extended import PathExtended
-    from machineconfig.scripts.python.helpers.helpers4 import search_for_files_of_interest
+    from machineconfig.scripts.python.helpers_fire.helpers4 import search_for_files_of_interest
     from machineconfig.utils.options import choose_from_options
     from machineconfig.utils.path_helper import match_file_name, sanitize_path
     path_obj = sanitize_path(layout_path)
@@ -132,11 +131,27 @@ def run(ctx: typer.Context,
         print(f"❌ Unsupported platform: {platform.system()}")
 
 
-def main_from_parser():
+def kill_process():
+    from machineconfig.utils.procs import main
+    main()
+
+def get_app():
     layouts_app = typer.Typer(help="Layouts management subcommands", no_args_is_help=True)
-    layouts_app.command("create-from-function", no_args_is_help=True)(create_from_function)
-    layouts_app.command("run", no_args_is_help=True)(run)
-    layouts_app.command("balance-load", no_args_is_help=True)(balance_load)
+    from machineconfig.scripts.python.sessions_helpers.sessions_multiprocess import create_from_function
+    layouts_app.command("create-from-function", no_args_is_help=True, help="[c] Create a layout from a function")(create_from_function)
+    layouts_app.command("c", no_args_is_help=True, help="Create a layout from a function", hidden=True)(create_from_function)
+    layouts_app.command("run", no_args_is_help=True, help="[r] Run the selected layout(s)")(run)
+    layouts_app.command("r", no_args_is_help=True, help="Run the selected layout(s)", hidden=True)(run)
+    layouts_app.command("balance-load", no_args_is_help=True, help="[b] Balance the load across sessions")(balance_load)
+    layouts_app.command("b", no_args_is_help=True, help="Balance the load across sessions", hidden=True)(balance_load)
+    layouts_app.command("kill-process", no_args_is_help=False, help="[k] Choose a process to kill")(kill_process)
+    layouts_app.command("k", no_args_is_help=False, help="Choose a process to kill", hidden=True)(kill_process)
+
+    return layouts_app
+
+
+def main():
+    layouts_app = get_app()
     layouts_app()
 
 
